
sortcl
======

**sort multiple angular power spectra in healpy input order**

This is a minimal Python package to sort input angular power spectra `cls`
into the order expected by healpy's `synalm` and `synfast` functions.

The package can be installed using pip:

    pip install sortcl

Then import the `sortcl` function from the package:

    from sortcl import sortcl

For more information, see the [documentation].

Current functionality covers the absolutely minimal use case.  Please open an
issue on GitHub if you would like to see anything added.

[documentation]: https://cltools.readthedocs.io/sortcl/
